@@ -29,7 +29,7 @@ Session = sessionmaker(class_=ContextSession)
 from flexget import config_schema, db_schema, logger, plugin
 from flexget.event import fire_event
 from flexget.ipc import IPCClient, IPCServer
-from flexget.options import CoreArgumentParser, get_parser, unicode_argv
+from flexget.options import CoreArgumentParser, get_parser, manager_parser, ParserError, unicode_argv
 from flexget.task import Task
 from flexget.task_queue import TaskQueue
 from flexget.utils.tools import pid_exists
@@ -137,7 +137,11 @@ class Manager(object):
 
         self.config = {}
 
-        self.options, extra = CoreArgumentParser().parse_known_args(args)
+        try:
+            self.options, extra = CoreArgumentParser().parse_known_args(args)
+        except ParserError:
+            # If a non-built-in command was used, we need to parse with a parser that doesn't define the subparsers
+            self.options, extra = manager_parser.parse_known_args(args)
         try:
             self.find_config(create=False)
         except:
@@ -567,14 +571,14 @@ class Manager(object):
         :raises: `ValueError` and rolls back to previous config if the provided config is not valid.
         """
         old_config = self.config
-        self.config = config
-        errors = self.validate_config()
-        if errors:
-            for error in errors:
-                log.critical("[%s] %s", error.json_pointer, error.message)
+        try:
+            self.config = self.validate_config(config)
+        except ValueError as e:
+            for error in getattr(e, 'errors', []):
+                log.critical('[%s] %s', error.json_pointer, error.message)
             log.debug('invalid config, rolling back')
             self.config = old_config
-            raise ValueError('Config did not pass schema validation')
+            raise
         log.debug('New config data loaded.')
         fire_event('manager.config_updated', self)
 
@@ -595,14 +599,26 @@ class Manager(object):
         for task in self.tasks:
             config_changed(task)
 
-    def validate_config(self):
+    def validate_config(self, config=None):
         """
-        Check all root level keywords are valid.
+        Check all root level keywords are valid. Config may be modified by before_config_validate hooks. Modified
+        config will be returned.
 
-        :returns: A list of `ValidationError`s
+        :param config: Config to check. If not provided, current manager config will be checked.
+        :raises: `ValueError` when config fails validation. There will be an `errors` attribute with the schema errors.
+        :returns: Final validated config.
         """
-        fire_event('manager.before_config_validate', self)
-        return config_schema.process_config(self.config)
+        if not config:
+            config = self.config
+        config = fire_event('manager.before_config_validate', config, self)
+        errors = config_schema.process_config(config)
+        if errors:
+            err = ValueError('Did not pass schema validation.')
+            err.errors = errors
+            raise err
+        else:
+            return config
+
 
     def init_sqlalchemy(self):
         """Initialize SQLAlchemy"""
