@@ -16,7 +16,7 @@ log = logging.getLogger('cron_env')
 def check_env(manager):
     persistence = SimplePersistence(plugin='cron_env')
     encoding = sys.getfilesystemencoding()
-    if manager.options.execute.cron:
+    if manager.options.cron:
         if 'terminal_encoding' in persistence:
             terminal_encoding = persistence['terminal_encoding']
             if terminal_encoding != encoding:
